################################################################################
#                                                                              #
#   Copyright (C) 1997-2000, Netegrity, Inc. All rights reserved               #
#                                                                              #
#   Netegrity, Inc. makes no representations concerning either the             #
#   merchantability of this software or the suitability of this software       #
#   for any particular purpose. It is provided "as is" without express         #
#   or implied warranty of any kind.                                           #
#                                                                              #
################################################################################
 
 
use Netegrity::PolicyMgtAPI;


#                                                                              #
# Begin site-specific configuration                                            #
# The follwing information should be changed before running this sample.       #
#                                                                              #
 
$adminName          = 'admin';
$adminPwd           = 'password';

$userdir_namespace  = 'LDAP:';
$userdir_server     = '127.0.0.1';  # IP Address if LDAP, Data Source Name if ODBC
$user_lookup_string = 'ou=People';  # Example: ou=People or name=jdoe

#
# LDAP User Directory Settings
#
$ldap_srchroot      = 'o=security.com';
$ldap_usrlkp_start  = '(&(uid=';
$ldap_usrlkp_end    = ')(objectclass=*))';
$ldap_usrname       = '';
$ldap_usrpwd        = '';
$ldap_require_creds = 0;

#
# Affiliate data
#
$password = "password";
$authURL = "http://www.authURL.com/sample";
$validityDuration = 60;
$affiliateAttrTypeHeader = 1;     # AFFILIATE_HTTP_HEADER_VARIABLE
 
#                                                                              #
# End site-specific configuration                                              #
#                                                                              #


$policymgtapi = Netegrity::PolicyMgtAPI->New();
$session = $policymgtapi->CreateSession($adminName, $adminPwd);
 
die "\nFATAL: Cannot create session. Please check admin credentials\n" 
    unless ($session != undef); 



showmenu();

 
sub showmenu {
    if($^O EQ 'MSWin32') { system('cls'); } else { system('clear');}

    print "\n\n*********** SiteMinder (SM) Affiliate Scripting Interface Demo  ***********\n";
    print "\n";
    print "\n";
    print "\tPlease make a selection from the following:\n";
    print "\n";
    print "\t[1] Setup Policy Store.\n";
    print "\t[2] Cleanup Policy Store.\n";
    print "\n";
    print "\t[9] Exit\t\t\t\t\t\t\n";
    print "\n";
    print "\tChoice: ";

    chomp($choice = <STDIN>);
    
    if($choice == 1) {
        setup_ps_store();
    } elsif ($choice == 2) {
        clean_ps_store();
    } elsif ($choice == 9) {
        exit(0);
    } else {
        print "Invalid Choice. Please make another selection.\n";
        showmenu();
    }
}

 

sub setup_ps_store {
 
    # Create a User Directory

    print "\tCreating User Directory \'affiliate-userdir\'...";

    if($userdir_namespace EQ 'ODBC:') {
        $odbc_queryscheme = $session->CreateODBCQueryScheme("transpolar-ODBCScheme");
    }

    $userdir = $session->CreateUserDir( "affiliate-userdir",
                                        $userdir_namespace,
                                        $userdir_server,
                                        $odbc_queryscheme,
                                        "Sample Affiliate User Directory",
                                        $ldap_srchroot,
                                        $ldap_usrlkp_start,
                                        $ldap_usrlkp_end,
                                        $ldap_usrname,
                                        $ldap_usrpwd,
                                        0,
                                        2,
                                        10,
                                        0,
                                        $ldap_require_creds
                                      );

    if(!defined $userdir) {
        die "\nFATAL: Unable to create User Directory \'affiliate-userdir\'\n";
    }

    print "done\n";


    # Create an Affiliate Domain

    print "\tCreating Affiliate Domain \'affiliate-domain\'...";

    $affdomain = $session->CreateAffDomain(   "affiliate-domain",
                                                    "Sample Affiliate Domain"
                                                );

    if(!defined $affdomain) {
        die "\nFATAL: Unable to create Affiliate Domain \'affiliate-domain\'\n";
    }

    $affdomain->AddUserDir($userdir);

    print "done\n";


    # Create an Affiliate

    print "\tCreating Affiliate \'affiliate\'...";

    $affiliate = $affdomain->CreateAffiliate(   "affiliate",
                                                $password,
                                                $authURL,
                                                $validityDuration,
                                                $skewTime
                                            );

    if(!defined $affiliate) {
        die "\nFATAL: Unable to create Affiliate \'affiliate\'\n";
    }

    print "done\n";


    # Add user to Affiliate

    print "\tAdding selected user to affiliate...";

    $user = $userdir->LookupEntry($user_lookup_string);

    if(defined $user) {
        $affiliate->AddUser($user);
        print "done\n";
    } else {
        print "user not found\n"
    }

    print "done\n";


    # Add attribute to Affiliate

    print "\tCreating Affiliate \'affiliate\'...";

    $affattr = $affiliate->AddAttribute(    $affiliateAttrTypeHeader,
                                            "staticHeaderName=staticHeaderValue"
                                        );

    if(!defined $affattr) {
        die "\nFATAL: Unable to create Affiliate Attribute \'staticHeaderName\'\n";
    }

    print "done\n";


    showmenu();
    
}


sub clean_ps_store {
    print "\n\tCleaning up...";
    $session->DeleteAffDomain($session->GetAffDomain("affiliate-domain"));
    $session->DeleteUserDir($session->GetUserDir("affiliate-userdir"));
    print "done\n";
    
    showmenu();
}
